@@ -1535,6 +1535,38 @@ STRUCT<str_col STRING>;
 -- Snowflake
 --------------------------------------
 
+# dialect: snowflake
+ABS(tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+ABS(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ASIN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ASINH(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ATAN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ATAN2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+ATANH(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+CBRT(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 AI_AGG('foo', 'bar');
 VARCHAR;
@@ -1611,6 +1643,22 @@ INT;
 CHARINDEX('world', 'hello world', 1);
 INT;
 
+# dialect: snowflake
+CEIL(3.14);
+DOUBLE;
+
+# dialect: snowflake
+CEIL(3.14::FLOAT, 1);
+FLOAT;
+
+# dialect: snowflake
+CEIL(3.14, 1);
+DOUBLE;
+
+# dialect: snowflake
+CEIL(10::NUMERIC);
+NUMBER;
+
 # dialect: snowflake
 CHAR(65);
 VARCHAR;
@@ -1623,6 +1671,10 @@ VARCHAR;
 COLLATE('hello', 'utf8');
 VARCHAR;
 
+# dialect: snowflake
+COSH(1.5);
+DOUBLE;
+
 # dialect: snowflake
 COMPRESS('Hello World', 'SNAPPY');
 BINARY;
@@ -1631,6 +1683,14 @@ BINARY;
 COMPRESS('Hello World', 'zlib(1)');
 BINARY;
 
+# dialect: snowflake
+DEGREES(PI()/3);
+DOUBLE;
+
+# dialect: snowflake
+DEGREES(1);
+DOUBLE;
+
 # dialect: snowflake
 DECOMPRESS_BINARY('compressed_data', 'SNAPPY');
 BINARY;
@@ -1639,6 +1699,22 @@ BINARY;
 DECOMPRESS_STRING('compressed_data', 'ZSTD');
 VARCHAR;
 
+# dialect: snowflake
+DIV0(10, 0);
+DOUBLE;
+
+# dialect: snowflake
+DIV0(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+DIV0NULL(10, 0);
+DOUBLE;
+
+# dialect: snowflake
+DIV0NULL(tbl.double_col, tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 LPAD('Hello', 10, '*');
 VARCHAR;
@@ -1667,6 +1743,14 @@ BINARY;
 COLLATION('hello');
 VARCHAR;
 
+# dialect: snowflake
+COT(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+COS(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 CONCAT('Hello', 'World!');
 VARCHAR;
@@ -1715,6 +1799,30 @@ INT;
 EDITDISTANCE('hello', 'world', 3);
 INT;
 
+# dialect: snowflake
+EXP(1);
+DOUBLE;
+
+# dialect: snowflake
+EXP(5.5);
+DOUBLE;
+
+# dialect: snowflake
+FACTORIAL(5);
+BIGINT;
+
+# dialect: snowflake
+FLOOR(42);
+INT;
+
+# dialect: snowflake
+FLOOR(135.135, 1);
+DOUBLE;
+
+# dialect: snowflake
+FLOOR(tbl.bigint_col, -1);
+BIGINT;
+
 # dialect: snowflake
 ENDSWITH('hello world', 'world');
 BOOLEAN;
@@ -1839,10 +1947,30 @@ INT;
 POSITION('abc', 'abcdef', 1);
 INT;
 
+# dialect: snowflake
+PI();
+DOUBLE;
+
+# dialect: snowflake
+POW(tbl.double_col, 2);
+DOUBLE;
+
+# dialect: snowflake
+RADIANS(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 LOWER(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+LN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+LOG(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 LTRIM('  hello world  ');
 VARCHAR;
@@ -1855,6 +1983,18 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+MOD(tbl.bigint_col, 3);
+BIGINT;
+
+# dialect: snowflake
+MOD(tbl.double_col, 2.5);
+DOUBLE;
+
+# dialect: snowflake
+MOD(42, 7);
+INT;
+
 # dialect: snowflake
 'foo' REGEXP 'bar';
 BOOLEAN;
@@ -1895,6 +2035,42 @@ DECIMAL(38, 0);
 REGEXP_COUNT('hello world', 'l', 1, 'i');
 DECIMAL(38, 0);
 
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1, 'i');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_EXTRACT_ALL('hello world', 'world', 1, 1, 'i', 0);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0, 'i');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_INSTR('hello world', 'world', 1, 1, 0, 'i', 1);
+DECIMAL(38, 0);
+
 # dialect: snowflake
 REGEXP_REPLACE('hello world', 'world', 'universe');
 VARCHAR;
@@ -1927,6 +2103,26 @@ VARCHAR;
 REGEXP_SUBSTR('hello world', 'world', 1, 1, 'e', NULL);
 VARCHAR;
 
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1);
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1, 'i');
+ARRAY;
+
+# dialect: snowflake
+REGEXP_SUBSTR_ALL('hello world', 'world', 1, 1, 'i', 0);
+ARRAY;
+
 # dialect: snowflake
 REPEAT('hello', 3);
 VARCHAR;
@@ -1963,6 +2159,26 @@ BINARY;
 REVERSE(NULL);
 VARCHAR;
 
+# dialect: snowflake
+ROUND(42);
+INT;
+
+# dialect: snowflake
+ROUND(tbl.bigint_col, -1);
+BIGINT;
+
+# dialect: snowflake
+ROUND(tbl.double_col, 0, 'HALF_TO_EVEN');
+DOUBLE;
+
+# dialect: snowflake
+SQUARE(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+TANH(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 RIGHT('hello world', 5);
 VARCHAR;
@@ -2079,10 +2295,30 @@ VARCHAR;
 SHA2_HEX('foo', null);
 VARCHAR;
 
+# dialect: snowflake
+SIN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+SINH(1);
+DOUBLE;
+
+# dialect: snowflake
+SINH(1.5);
+DOUBLE;
+
+# dialect: snowflake
+SIGN(tbl.double_col);
+INT;
+
 # dialect: snowflake
 SOUNDEX(tbl.str_col);
 VARCHAR;
 
+# dialect: snowflake
+SOUNDEX_P123('test');
+VARCHAR;
+
 # dialect: snowflake
 SPACE(5);
 VARCHAR;
@@ -2095,6 +2331,10 @@ VARCHAR;
 SPACE(NULL);
 VARCHAR;
 
+# dialect: snowflake
+SQRT(tbl.double_col);
+DOUBLE;
+
 # dialect: snowflake
 SPLIT('hello world', ' ');
 ARRAY;
@@ -2111,6 +2351,18 @@ ARRAY;
 SPLIT_PART('11.22.33', '.', 1);
 VARCHAR;
 
+# dialect: snowflake
+STRTOK('hello world');
+VARCHAR;
+
+# dialect: snowflake
+STRTOK('hello world', ' ');
+VARCHAR;
+
+# dialect: snowflake
+STRTOK('a.b.c', '.', 1);
+VARCHAR;
+
 # dialect: snowflake
 STARTSWITH('hello world', 'hello');
 BOOLEAN;
@@ -2127,6 +2379,30 @@ BOOLEAN;
 STARTSWITH(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+SEARCH(line, 'king');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH((play, line), 'dream');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', ANALYZER => 'UNICODE_ANALYZER');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', SEARCH_MODE => 'OR');
+BOOLEAN;
+
+# dialect: snowflake
+SEARCH(line, 'king', ANALYZER => 'UNICODE_ANALYZER', SEARCH_MODE => 'AND');
+BOOLEAN;
+
+# dialect: snowflake
+STRTOK_TO_ARRAY('a,b,c', ',');
+ARRAY;
+
 # dialect: snowflake
 SUBSTR('hello world', 1, 5);
 VARCHAR;
@@ -2143,6 +2419,18 @@ BINARY;
 SUBSTR(tbl.str_col, NULL);
 STRING;
 
+# dialect: snowflake
+TAN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+TRANSLATE('hello world', 'elo', 'XYZ');
+VARCHAR;
+
+# dialect: snowflake
+UNICODE('€');
+INT;
+
 # dialect: snowflake
 TRIM('hello world');
 VARCHAR;
@@ -2282,3 +2570,7 @@ OBJECT;
 # dialect: tsql
 SYSDATETIMEOFFSET();
 TIMESTAMPTZ;
+
+# dialect: tsql
+RADIANS(90);
+INT;
